@@ -17,8 +17,17 @@ DayHistory::DayHistory(QWidget *parent) :
 
 void DayHistory::showInfo(QModelIndex index)
 {
+    QString name, group;
+    int mid;
+
+    mid = index.data().toString().indexOf("/");
+    group = index.data().toString().left(mid);
+    mid = index.data().toString().count() - mid;
+    name = index.data().toString().right(mid);
+
+
     hiw = new HistoryInfoWindow(this);
-    hiw->load(index.data().toString());
+    hiw->load(name,group);
     hiw->show();
 }
 
@@ -36,10 +45,7 @@ void DayHistory::load(QString date)
         name = tmp.takeFirst();
         group = tmp.takeFirst();
 
-        if(group != "Cardio")
-            model->appendRow(new QStandardItem(group + "/" + name ));
-        else
-            model->appendRow(new QStandardItem(group + "/" + name ));
+        model->appendRow(new QStandardItem(group + "/" + name ));
     }
 
 }
