@@ -95,9 +95,9 @@ void ExerciseWindow::loadExercise(QList<QString> name)
 
     while(!list.isEmpty())
     {
-        status[i] = list.takeLast();
-        reps[i] = list.takeLast();
-        weight[i] = list.takeLast();
+        status[i] = list.takeFirst();
+        reps[i] = list.takeFirst();
+        weight[i] = list.takeFirst();
 
         i++;
     }
@@ -135,6 +135,8 @@ void ExerciseWindow::loadExercise(QList<QString> name)
         set = SET; min = MIN; sec = SEC;
         strSet.setNum(SET); strMin.setNum(MIN);  strSec.setNum(SEC);
 
+        wdCount = 2;
+
         if(weight[currentSet] != "")
             label->setText("Exercise: " + currentExercise +  "\nShake when set is done." +
                            "\nLast time on this set: " + weight[currentSet] + "x"  +
@@ -186,9 +188,9 @@ void ExerciseWindow::setCurrentExercise(QString name)
 
     while(!list.isEmpty())
     {
-        status[i] = list.takeLast();
-        reps[i] = list.takeLast();
-        weight[i] = list.takeLast();
+        status[i] = list.takeFirst();
+        reps[i] = list.takeFirst();
+        weight[i] = list.takeFirst();
 
         i++;
     }
@@ -205,6 +207,8 @@ void ExerciseWindow::setCurrentExercise(QString name)
     set = SET; min = MIN; sec = SEC;
     strSet.setNum(SET); strMin.setNum(MIN);  strSec.setNum(SEC);
 
+    wdCount = 2;
+
     if(weight[currentSet] != "")
         label->setText("Exercise: " + currentExercise +  "\nShake when set is done." +
                        "\nLast time on this set: " + weight[currentSet] + "x"  +
@@ -393,7 +397,6 @@ void ExerciseWindow::checkAcc(QString x)
 
 void ExerciseWindow::shaked()
 {
-    currentReps = "4";
     currentSet++;
     QDBusMessage reply;
     if(set == -1)
@@ -426,7 +429,7 @@ void ExerciseWindow::shaked()
 
             wd = new WeightDialog(this);
             connect(wd,SIGNAL(next()),this,SLOT(openED()));
-            wd->load(currentExercise, currentGroup,currentReps);
+            wd->load(currentExercise, currentGroup,"1");
             wd->show();
             return;
         }
@@ -436,13 +439,13 @@ void ExerciseWindow::shaked()
             btnShake->setEnabled(false);
 
             wd = new WeightDialog(this);
-            wd->load(currentExercise, currentGroup, currentReps);
+            wd->load(currentExercise, currentGroup,"1");
             wd->show();
             return;
         }
 
         wd = new WeightDialog(this);
-        wd->load(currentExercise, currentGroup, currentReps);
+        wd->load(currentExercise, currentGroup, "1");
         wd->show();
     }
 
@@ -459,6 +462,28 @@ void ExerciseWindow::shaked()
     myThread->quit(); //stop check accelerometer
 }
 
+void ExerciseWindow::reopenWD()
+{
+    QString str;
+
+    if(wdCount > SET)
+    {
+        if(exercises.count() > 1)
+            openED();
+        return;
+    }
+    else
+    {
+        str.setNum(wdCount);
+        wd = new WeightDialog(this);
+        wd->load(currentExercise, currentGroup, str);
+        connect(wd,SIGNAL(next()),this,SLOT(reopenWD()));
+        wd->show();
+    }
+    wdCount++;
+}
+
+
 void ExerciseWindow::vibrate()
 {
     QDBusMessage reply;
