@@ -86,7 +86,7 @@ void NewExerciseWindow::savePic2()
 
 void NewExerciseWindow::saveExercise()
 {
-
+    qDebug () << "save new exercise 1";
     if(txtName->text() == "")
     {
         QMaemo5InformationBox::information(this, "You must fill in name.", QMaemo5InformationBox::DefaultTimeout);
@@ -102,7 +102,7 @@ void NewExerciseWindow::saveExercise()
         QMaemo5InformationBox::information(this, "You must choose a group.", QMaemo5InformationBox::DefaultTimeout);
         return;
     }
-
+    qDebug () << "save new exercise 2";
     QString name = txtName->text();
     QString group = btnGroup->valueText();
     QString muscle = txtMuscle->text();
@@ -111,9 +111,15 @@ void NewExerciseWindow::saveExercise()
     QDir dir;
 
     if(group == "Cardio")
+    {
+        qDebug () << "save new exercise 3";
         xml->saveCardio(name);
+    }
     else
+    {
+        qDebug () << "save new exercise 4";
         xml->saveEx(name,group,muscle,info);
+    }
     //if saved OK
     if(pic1 != "")
     {
@@ -133,9 +139,9 @@ void NewExerciseWindow::saveExercise()
     QMaemo5InformationBox::information(this, "Exercise saved.",
                                                 QMaemo5InformationBox::DefaultTimeout);
     emit closed();
-    //this->destroy();
+    this->destroy();
 
-    this->hide();
+    //this->hide();
 }
 
 #
